!function(e){var t={};function n(o){if(t[o])return t[o].exports;var r=t[o]={i:o,l:!1,exports:{}};return e[o].call(r.exports,r,r.exports,n),r.l=!0,r.exports}n.m=e,n.c=t,n.d=function(e,t,o){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:o})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var o=Object.create(null);if(n.r(o),Object.defineProperty(o,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)n.d(o,r,function(t){return e[t]}.bind(null,r));return o},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=1)}([function(e,t){e.exports=function(e){return e&&e.__esModule?e:{default:e}}},function(e,t,n){"use strict";var o=n(0);Object.defineProperty(t,"__esModule",{value:!0}),Object.defineProperty(t,"OGVCompat",{enumerable:!0,get:function(){return u.default}}),t.OGVVersion=void 0;var r=o(n(2)),u=o(n(3));t.OGVVersion="1.6.1-20190618150123-e65cc4a","object"===("undefined"==typeof window?"undefined":(0,r.default)(window))&&(window.OGVCompat=u.default,window.OGVVersion="1.6.1-20190618150123-e65cc4a")},function(e,t){function n(e){return(n="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function o(t){return"function"==typeof Symbol&&"symbol"===n(Symbol.iterator)?e.exports=o=function(e){return n(e)}:e.exports=o=function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":n(e)},o(t)}e.exports=o},function(e,t,n){"use strict";var o=n(0);Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=o(n(4)),u=o(n(5)),i=o(n(6)),f=new(function(){function e(){(0,r.default)(this,e),this.benchmark=new i.default}return(0,u.default)(e,[{key:"hasTypedArrays",value:function(){return!!window.Uint32Array}},{key:"hasWebAudio",value:function(){return!(!window.AudioContext&&!window.webkitAudioContext)}},{key:"hasFlash",value:function(){if(-1!==navigator.userAgent.indexOf("Trident"))try{new ActiveXObject("ShockwaveFlash.ShockwaveFlash");return!0}catch(e){return!1}return!1}},{key:"hasAudio",value:function(){return this.hasWebAudio()||this.hasFlash()}},{key:"isBlacklisted",value:function(e){var t=!1;return[/\(i.* OS [6789]_.* like Mac OS X\).* Mobile\/.* Safari\//,/\(Macintosh.* Version\/6\..* Safari\/\d/].forEach(function(n){e.match(n)&&(t=!0)}),t}},{key:"isSlow",value:function(){return this.benchmark.slow}},{key:"isTooSlow",value:function(){return this.benchmark.tooSlow}},{key:"supported",value:function(e){return"OGVDecoder"===e?this.hasTypedArrays()&&!this.isBlacklisted(navigator.userAgent):"OGVPlayer"===e&&(this.supported("OGVDecoder")&&this.hasAudio()&&!this.isTooSlow())}}]),e}());t.default=f},function(e,t){e.exports=function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}},function(e,t){function n(e,t){for(var n=0;n<t.length;n++){var o=t[n];o.enumerable=o.enumerable||!1,o.configurable=!0,"value"in o&&(o.writable=!0),Object.defineProperty(e,o.key,o)}}e.exports=function(e,t,o){return t&&n(e.prototype,t),o&&n(e,o),e}},function(e,t,n){"use strict";e.exports=function(){var e,t=this;e=window.performance&&window.performance.now?function(){return window.performance.now()}:function(){return Date.now()};var n=null;Object.defineProperty(t,"speed",{get:function(){return null===n&&function(){var t=0,o=e();!function e(n){return t++,n<2?n:e(n-2)+e(n-1)}(30);var r=e()-o;n=t/r}(),n}}),Object.defineProperty(t,"slowCutoff",{get:function(){return 5e4}}),Object.defineProperty(t,"tooSlowCutoff",{get:function(){return 0}}),Object.defineProperty(t,"slow",{get:function(){return t.speed<t.slowCutoff}}),Object.defineProperty(t,"tooSlow",{get:function(){return t.speed<t.tooSlowCutoff}})}}]);